package com.lodgon.embeddedglassfish.jdbcpoolnotfound;

import static org.testng.Assert.*;
import org.testng.annotations.*;

import java.util.HashMap;
import java.util.Map;

import javax.ejb.embeddable.EJBContainer;
import javax.naming.Context;
import javax.naming.NamingException;

public class SimpleBeanTest {
  private static final String APP_NAME = "jdbcpoolnotfound";

  private static EJBContainer ejbContainer;
  private static Context ctx;

  private static SimpleBean simpleBean;

  @BeforeClass
  public static void setUpClass() throws Exception {
    Map<String, Object> properties = new HashMap<String, Object>();
    properties.put("org.glassfish.ejb.embedded.glassfish.installation.root", "./src/test/resources/glassfish");
    properties.put(EJBContainer.APP_NAME, APP_NAME);
    ejbContainer = EJBContainer.createEJBContainer(properties);
    ctx = ejbContainer.getContext();
    simpleBean = lookup(SimpleBean.class);
  }

  private static <T> T lookup(Class<T> type) throws NamingException {
    return (T) ctx.lookup("java:global/" + APP_NAME + "/classes/" + type.getSimpleName());
  }

  @AfterClass
  public static void tearDownClass() {
    if (ejbContainer != null) ejbContainer.close();
  }

  @Test
  public void createSimpleEntity() {
    SimpleEntity simpleEntity = new SimpleEntity();
    simpleEntity.setName("simple_name");

    SimpleEntity createdSimpleEntity = simpleBean.create(simpleEntity);
    assertNotNull(createdSimpleEntity);
    assertNotSame(createdSimpleEntity.getId(), 0L);
    assertEquals(createdSimpleEntity.getName(), "simple_name");

    SimpleEntity foundSimpleEntity = simpleBean.find(createdSimpleEntity.getId());
    assertNotNull(foundSimpleEntity);
    assertNotSame(foundSimpleEntity.getId(), createdSimpleEntity.getId());
    assertEquals(foundSimpleEntity.getName(), "simple_name");

    simpleBean.delete(createdSimpleEntity.getId());
    foundSimpleEntity = simpleBean.find(createdSimpleEntity.getId());
    assertNull(foundSimpleEntity);
  }
}
